[Catalyst-commits] r11290 - Catalyst-Plugin-Authentication/0.10000/branches/moose/lib/Catalyst/Plugin

uazz at dev.catalyst.perl.org uazz at dev.catalyst.perl.org
Tue Sep 1 09:39:58 GMT 2009


Author: uazz
Date: 2009-09-01 09:39:58 +0000 (Tue, 01 Sep 2009)
New Revision: 11290

Modified:
   Catalyst-Plugin-Authentication/0.10000/branches/moose/lib/Catalyst/Plugin/Authentication.pm
Log:
Move init stuff to before 'setup_finalize'


Modified: Catalyst-Plugin-Authentication/0.10000/branches/moose/lib/Catalyst/Plugin/Authentication.pm
===================================================================
--- Catalyst-Plugin-Authentication/0.10000/branches/moose/lib/Catalyst/Plugin/Authentication.pm	2009-09-01 09:38:17 UTC (rev 11289)
+++ Catalyst-Plugin-Authentication/0.10000/branches/moose/lib/Catalyst/Plugin/Authentication.pm	2009-09-01 09:39:58 UTC (rev 11290)
@@ -190,14 +190,14 @@
 
 }
 
-# we can't actually do our setup in setup because the model has not yet been loaded.  
-# So we have to trigger off of setup_finished.  :-(
-sub setup {
+# We can't actually do our setup in setup because the model has not yet been loaded.  
+# So we have to trigger before 'setup_finalize'.
+before 'setup_finalize' => sub {
     my $app = shift;
 
+    $app->mk_classdata('_auth_initialized');
     $app->_authentication_initialize();
-    $app->next::method(@_);
-}
+};
 
 ## the actual initialization routine. whee.
 sub _authentication_initialize {




More information about the Catalyst-commits mailing list